/*
 * Copyright (c) 2004 - 2007, Tranql project contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/**
 * This Class was added to address the loss of getProperties methods on the Client
 * DataSources.  The Derby attributes are managed as a string where:
 * 
 *    key=value[;] 
 *    
 *    The above values are parsed into properties used for key=value pairs.  This
 *    class will take a list of attributes and allow the caller to manipulate them.
 */

package org.tranql.connector.derby.attributes;

import java.util.Enumeration;
import java.util.Properties;
import java.util.StringTokenizer;

public class Attributes {
	private Properties props = new Properties();

	public Attributes() {
	}

	public Attributes(String attr) throws ParseException {
		super();
		if (attr != null)
			parseAttributes(attr);
	}

	private void parseAttributes(String attr) throws ParseException {
		StringTokenizer st = new StringTokenizer(attr, ";");
		while (st.hasMoreElements()) {
			String singleAttr = st.nextToken();
			StringTokenizer kv = new StringTokenizer(singleAttr, "=");
			if (kv.countTokens() != 2)
				throw new ParseException("Attribute of \"" + singleAttr
						+ "\" is malformed.  Entire attribute string is \""
						+ attr + "\"");
			props.setProperty(kv.nextToken(), kv.nextToken());
		}
	}

	public String toString() {
		Enumeration keys = props.keys();
		StringBuffer sb = new StringBuffer();
		while (keys.hasMoreElements()) {
			String key = (String) keys.nextElement();
			String value = (String) props.get(key);
			sb.append(key + "=" + value);
			if (keys.hasMoreElements())
				sb.append(";");
		}
		return sb.toString();
	}

	public String getAttributeValue(String key) {
		return props.getProperty(key);
	}

	public void setAttributeValue(String key, String value) {
		props.setProperty(key, value);
	}

	public void remove(String key) {
		props.remove(key);
	}
}
